<template>
  <div class="notice">
    <el-dialog
        v-model="dialogVisible"
        width="900px"
        :before-close="handleClose"
        :close-on-press-escape="false"
        :close-on-click-modal="false"
    >
      <template #header>
        <div style="text-align: center; width: 100%;font-size: 18px;font-weight: 600">
          <span>{{title}}仓库</span>
        </div>
      </template>
      <el-form :model="state.form" size="default" ref="busRef" :rules="state.formRules" label-width="117px" >
        <el-form-item>
          <div style="font-size: 16px;font-weight: 600;margin-top: -25px;margin-left: -110px;margin-bottom: -15px">仓库基本信息</div>
        </el-form-item>
        <el-row :gutter="24">
          <el-col :span="12">
            <el-form-item label="仓库名称:" prop="name" >
              <el-input v-model="state.form.name" placeholder="请输入仓库名称"></el-input>
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item label="仓库面积:" prop="name" >
              <el-input v-model="state.form.name" placeholder="请输入仓库面积"></el-input>
            </el-form-item>
          </el-col>
        </el-row>
        <el-row :gutter="24">
          <el-col :span="12">
            <el-form-item label="仓库编号:" prop="name" >
              <el-input v-model="state.form.name" placeholder="请输入仓库编号"></el-input>
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item label="核定药量:" prop="name" >
              <el-input v-model="state.form.name" placeholder="请输入核定药量"></el-input>
            </el-form-item>
          </el-col>
        </el-row>
        <el-row :gutter="24">
          <el-col :span="12">
            <el-form-item label="危险等级:" prop="name" >
              <el-select
                  v-model="state.form.typeId"
                  placeholder="请选择"
                  style="width: 100%"
              >
                <el-option
                    v-for="item in state.typeList"
                    :key="item.id"
                    :label="item.name"
                    :value="item.id"
                />
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item label="核定人员数量:" prop="name" >
              <el-input v-model="state.form.name" placeholder="请输入核定人员数量"></el-input>
            </el-form-item>
          </el-col>
        </el-row>
      </el-form>
      <div style="display: flex;align-items: center">
        <div style="font-size: 16px;font-weight: 600;margin: 10px">库房列表</div>
        <el-button style="margin-left: 10px" type="primary" @click="addRoom">新增库房</el-button>
      </div>
      <el-table :data="state.storeroomList" style="width: 100%;margin-top: 15px" border>
        <el-table-column label="序号" type="index" align="center" width="80" />
        <el-table-column prop="name" label="库房名称" align="center">
          <template #default="{ row }">
            <el-form :model="row" :rules="rules">
              <el-form-item prop="name">
                <el-input
                    v-model="row.name"
                />
              </el-form-item>
            </el-form>
          </template>
        </el-table-column>
        <el-table-column prop="code" label="库房编号" align="center">
          <template #default="{ row }">
            <el-form :model="row" :rules="rules">
              <el-form-item prop="code">
                <el-input
                    v-model="row.code"
                />
              </el-form-item>
            </el-form>
          </template>
        </el-table-column>
        <el-table-column prop="area" label="面积" align="center">
          <template #default="{ row }">
            <el-form :model="row" :rules="rules">
              <el-form-item prop="area">
                <el-input
                    v-model="row.area"
                />
              </el-form-item>
            </el-form>
          </template>
        </el-table-column>
        <el-table-column prop="level" label="危险等级" align="center">
          <template #default="{ row }">
            <el-form :model="row" :rules="rules">
              <el-form-item prop="level">
                <el-input
                    v-model="row.level"
                />
              </el-form-item>
            </el-form>
          </template>
        </el-table-column>
        <el-table-column prop="level" label="核定药量" align="center">
          <template #default="{ row }">
            <el-form :model="row" :rules="rules">
              <el-form-item prop="level">
                <el-input
                    v-model="row.level"
                />
              </el-form-item>
            </el-form>
          </template>
        </el-table-column>
        <el-table-column prop="num" label="核定人员" align="center">
          <template #default="{ row }">
            <el-form :model="row" :rules="rules" >
              <el-form-item prop="num" >
                <el-input
                    v-model="row.num"

                />
              </el-form-item>
            </el-form>
          </template>
        </el-table-column>
        <el-table-column label="操作" align="center" class-name="small-padding fixed-width" >
          <template #default="scope">
            <el-button link type="danger" @click="delRoom(scope.row)">删除</el-button>
          </template>
        </el-table-column>
      </el-table>
      <template #footer>
        <span class="dialog-footer">
            <el-button @click="handleClose" size="default">取 消</el-button>
            <el-button type="primary"  @click="onSubmit" size="default" v-preReClick>确认</el-button>
        </span>
      </template>
    </el-dialog>
  </div>
</template>
<script setup>
import {reactive, ref, toRefs} from 'vue'
import {ElMessage} from "element-plus";
import {listDept} from "@/api/system/dept";
import {listUser} from "@/api/system/user";
import {addTemplate, editTemplate} from "@/api/signAgreement/template";
import {addType, editType, getSignType} from "@/api/signAgreement/signType";
import {getInfo} from "@/api/login";
import {getToken} from "@/utils/auth";
import {verifyPhone} from "@/utils/validate";

const uploadFileUrl = ref(import.meta.env.VITE_APP_BASE_API + "/common/upload"); // 上传文件服务器地址
const { proxy } = getCurrentInstance();
const dialogVisible = ref(false);
const title = ref("");
const busRef = ref();
const length = ref()
const emit = defineEmits(["getList"]);
const startPhone = ref('');
const validateUserPhone = (rule, value, callback)=>{
  if(value === ''){
    callback(new Error('请输入手机号'))
  }else if(state.title == '编辑' && value == startPhone.value){
    callback()
  } else{
    if(!verifyPhone(value)){
      callback(new Error('手机号格式有误'))
    }
  }
}
const state = reactive({
  form: {
    id: '',
    name: '',
    typeId:null,
    phone: '',
  },
  typeList: [
    {
      id: 1,
      name: '法定代表人'
    },
    {
      id: 2,
      name: '主要负责人'
    },
    {
      id: 3,
      name: '安全负责人'
    },
    {
      id: 4,
      name: '保管员'
    },
    {
      id: 5,
      name: '守护员'
    },
  ],
  storeroomList: [],
  formRules:{
    name: [{ required: true, trigger: "blur", message:'请输入姓名' }],
    phone: [{ required: true, trigger: "blur", validator: validateUserPhone }],
    typeId: [{ required: true, trigger: "blur", message:'请选择人员类型' }],
  },
})
const rules = {
  name: [
    { required: true, message: "姓名不能为空", trigger: "blur" },
  ],
};



const openDialog = async (type,value) => {
  title.value = type === 'add' ? '新增' : '编辑'
  if(type === 'edit') {
    state.form = JSON.parse(JSON.stringify(value))
    startPhone.value = value.phone
  }
  dialogVisible.value = true;
}

const onSubmit = async () => {
  console.log('form',state.form)
  const valid = await busRef.value.validate();

  if(valid){
    if(title.value === '新增'){
      const {id,fileList, ...data} = JSON.parse(JSON.stringify(state.form))
      // const res = await addTemplate(data)
      // if(res.code === 200){
      //   ElMessage({
      //     type: 'success',
      //     message: '新增成功'
      //   });
      // }else{
      //   ElMessage.warning(res.message)
      // }
      emit("getList")
      busRef.value.clearValidate();
      reset();
      dialogVisible.value = false;
    }else if(title.value === '编辑'){
      const {...data} = JSON.parse(JSON.stringify(state.form))
      const res = await editTemplate(data)
      // if(res.code === 200){
      //   ElMessage({
      //     type: 'success',
      //     message: '编辑成功'
      //   });
      // }else{
      //   ElMessage.warning(res.message)
      // }
      emit("getList")
      busRef.value.clearValidate();
      reset();
      dialogVisible.value = false;
    }

  }
}

const addRoom = () => {
  state.storeroomList.push({})
}

const delRoom = (val) => {
  console.log('val',val)
  if(Object.keys(val).length === 0){
    const index = state.storeroomList.findIndex(item => Object.keys(item).length === 0)
    if(index != -1){
      state.storeroomList.splice(index,1)
    }
  }else {
    const index = state.storeroomList.findIndex(item => item == val)
    if(index != -1){
      state.storeroomList.splice(index,1)
    }
  }

}

const handleClose = () => {
  busRef.value.clearValidate();
  reset();
  dialogVisible.value = false;
  emit("getList")
}
const reset = () => {
  state.form = {
    id: '',
    name: '',
    typeId:null,
    phone: '',
  }
  state.storeroomList = []
}
defineExpose({
  openDialog
});

</script>

<style scoped lang="scss">
.notice{
  :deep(.el-form .el-form-item__label) {
    font-size: 15px;
  }
  :deep(.el-form-item__content) {
    width: 100%;
  }
  .file {
    display: flex;
    flex-direction: column;
    align-items: flex-start;
  }
  .custom-iframe {
    border: 1px solid #9b9999;
    /* 隐藏原生滚动条 */
    overflow: hidden;
  }
}
</style>
